@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies
-   Copyright (C) 2009 Sergey Poznyakoff
+   Copyright (C) 2009-2016 Sergey Poznyakoff
   
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,16 +21,19 @@ struct acl_input
 {
   struct sockaddr *addr;
   socklen_t addrlen;
-  const char *user;
-  const char **groups;
+  pies_identity_t identity;
 };
 
 pies_acl_t pies_acl_create (const char *name, grecs_locus_t *locus);
+void pies_acl_destroy (pies_acl_t *pacl);
+void pies_acl_free (pies_acl_t acl);
+void pies_acl_use (pies_acl_t acl);
+int pies_acl_cmp (struct pies_acl *a, struct pies_acl *b);
 int pies_acl_check (pies_acl_t acl, struct acl_input *input, int result);
 int parse_acl_line (grecs_locus_t *locus, int allow, pies_acl_t acl,
 		    grecs_value_t *value);
 pies_acl_t pies_acl_lookup (const char *name);
-int pies_acl_install (pies_acl_t acl, grecs_locus_t * locus);
+pies_acl_t pies_acl_install (pies_acl_t acl);
 
 int assert_grecs_value_type (grecs_locus_t *locus,
 			     const grecs_value_t *value, int type);
